==> 11.4.2.tar.gz: webid-digital-signing-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdDigitalSigningPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdDigitalSigningPlugin", targets: ["WebIdDigitalSigningPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-plugin-core-spm.git",
            .exact("12.3.3")
        ),
        .package(
            name: "WebIdSdkUiKitComponents",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-sdk-ui-components-spm.git",
            .exact("9.3.1")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdDigitalSigningPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/internal/de/webid-solutions/WebIdDigitalSigningPlugin/11.4.2/WebIdDigitalSigningPlugin.framework-v11.4.2.zip",
            checksum: "271acb7562e74ebca35c7d731e63b61c54618a796c021688c6b8d9033466eb05"
        ),
        .target(
            name: "WebIdDigitalSigningPluginWrapper",
            dependencies: [
                .target(name: "WebIdDigitalSigningPlugin"),
                // [target dependecies here]
                
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "WebIdSdkUiKitComponents", package: "WebIdSdkUiKitComponents"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)

==> 12.4.0.tar.gz: webid-digital-signing-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdDigitalSigningPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdDigitalSigningPlugin", targets: ["WebIdDigitalSigningPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-plugin-core-spm.git",
            .exact("13.5.0")
        ),
        .package(
            name: "WebIdSdkUiKitComponents",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-sdk-ui-components-spm.git",
            .exact("10.3.1")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdDigitalSigningPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/redesign-v4/de/webid-solutions/WebIdDigitalSigningPlugin/12.4.0/WebIdDigitalSigningPlugin.framework-v12.4.0.zip",
            checksum: "6ec58c15b779ef76a48a0a24e3b1f8255860d54f3e779c652f2600e7f24dc692"
        ),
        .target(
            name: "WebIdDigitalSigningPluginWrapper",
            dependencies: [
                .target(name: "WebIdDigitalSigningPlugin"),
                // [target dependecies here]
                
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "WebIdSdkUiKitComponents", package: "WebIdSdkUiKitComponents"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)
